@@ -31,6 +31,8 @@ from functools import partial
 from . import ChipWhispererGlitch
 from chipwhisperer.common.utils import util
 
+from chipwhisperer.logging import *
+
 CODE_READ = 0x80
 CODE_WRITE = 0xC0
 ADDR_DATA = 33
@@ -832,7 +834,10 @@ class ChipWhispererExtra(object):
         #self.cwADV = CWAdvTrigger()
 
         self.cwEXTRA = CWExtraSettings(oa, cwtype)
-        self.enableGlitch = True
+        if cwtype == "cwhusky":
+            self.enableGlitch = True # TODO: temporary
+        else:
+            self.enableGlitch = True
         if self.enableGlitch:
             self.glitch = ChipWhispererGlitch.ChipWhispererGlitch(cwtype, scope, oa)
 
@@ -902,6 +907,11 @@ class CWExtraSettings(object):
             hasGlitchOut=True
             hasPLL=False
             hasAux=True
+        elif cwtype == "cwhusky":
+            hasFPAFPB=False
+            hasGlitchOut=False # TODO-temporary
+            hasPLL=False
+            hasAux=False
         else:
             raise ValueError("Unknown ChipWhisperer: %s" % cwtype)
 
@@ -1380,7 +1390,7 @@ class CWPLLDriver(object):
         if bnew != bold:
             self.writeByte(11, bnew)
 
-        logging.debug('%x, %x' % (bnew, self.readByte(11)))
+        scope_logger.debug('%x, %x' % (bnew, self.readByte(11)))
 
     def readByte(self, regaddr, slaveaddr=0x69):
         d = bytearray([0x00, 0x80 | 0x69, 0x80 |  regaddr])
