@@ -38,6 +38,8 @@ glitchreadbackaddr = 56
 CODE_READ       = 0x80
 CODE_WRITE      = 0xC0
 
+from chipwhisperer.logging import *
+
 # sign extend b low bits in x
 # from "Bit Twiddling Hacks"
 def SIGNEXT(x, b):
@@ -242,7 +244,7 @@ class GlitchSettings(util.DisableNewAttr):
             raise UserWarning("Can't use glitch offset %s - rounding into [%s, %s]" % (value, self.cwg._min_offset, self.cwg._max_offset))
 
         if value < -45:
-            logging.warning("Negative offsets <-45 may result in double glitches!")
+            glitch_logger.warning("Negative offsets <-45 may result in double glitches!")
         self.cwg.setGlitchOffset(value)
 
     @property
@@ -503,10 +505,14 @@ class ChipWhispererGlitch(object):
                 settingprefix = "cw1200"
                 partialbasename = "cw1200"
                 self.glitchPR = pr.PartialReconfigDataMulti()
+            elif cwtype == "cwhusky":
+                settingprefix = "cwhusky"
+                partialbasename = "cwhusky"
+                self.glitchPR = None
             else:
                 raise ValueError("Invalid ChipWhisperer Mode: %s" % cwtype)
 
-            if scope.getFWConfig().loader._release_mode != "debug":
+            if scope.getFWConfig().loader._release_mode != "debug" and cwtype != "cwhusky": # TODO- temporary
 
                 if scope.getFWConfig().loader._release_mode == "builtin":
                     filelike = scope.getFWConfig().loader._bsBuiltinData
@@ -516,10 +522,10 @@ class ChipWhispererGlitch(object):
                     if zipfile.is_zipfile(fileloc):
                         zfile = zipfile.ZipFile(fileloc, "r")
                     else:
-                        logging.warning('Partial Reconfiguration DISABLED: no zip-file for FPGA')
+                        glitch_logger.warning('Partial Reconfiguration DISABLED: no zip-file for FPGA')
                         zfile = None
                 else:
-                    logging.warning('Partial Reconfiguration DISABLED: no PR data for FPGA')
+                    glitch_logger.warning('Partial Reconfiguration DISABLED: no PR data for FPGA')
                     zfile = None
                     raise ValueError("Unknown FPGA mode: %s"%scope.getFWConfig().loader._release_mode)
 
@@ -530,17 +536,17 @@ class ChipWhispererGlitch(object):
                 else:
                     self.prEnabled = False
             else:
-                logging.warning('Partial Reconfiguration DISABLED: Debug bitstream mode')
+                glitch_logger.warning('Partial Reconfiguration DISABLED: Debug bitstream mode')
                 self.prEnabled = False
 
         except IOError as e:
-            logging.error(str(e))
+            glitch_logger.error(str(e))
             self.prEnabled = False
         except ValueError as e:
-            logging.error(str(e))
+            glitch_logger.error(str(e))
             self.prEnabled = False
         except OSError as e:  # Also catches WindowsError
-            logging.error(str(e))
+            glitch_logger.error(str(e))
             self.prEnabled = False
 
         if self.prEnabled:
@@ -561,7 +567,7 @@ class ChipWhispererGlitch(object):
             # Check this is actually working
             if self.prCon.isPresent() == False:
                 self.prEnabled = False
-                logging.warning('Partial Reconfiguration block not detected, PR disabled')
+                glitch_logger.warning('Partial Reconfiguration block not detected, PR disabled')
                 return
 
             # Reset FPGA back to defaults in case previous bitstreams loaded
@@ -578,10 +584,10 @@ class ChipWhispererGlitch(object):
             return
 
         if self._width == 0:
-            logging.warning('Partial reconfiguration for width = 0 may not work')
+            glitch_logger.warning('Partial reconfiguration for width = 0 may not work')
 
         if self._offset == 0:
-            logging.warning('Partial reconfiguration for offset = 0 may not work')
+            glitch_logger.warning('Partial reconfiguration for offset = 0 may not work')
 
         bs = self.glitchPR.getPartialBitstream([self._width, self._offset])
 
@@ -668,7 +674,7 @@ class ChipWhispererGlitch(object):
         current = self.oa.sendMessage(CODE_READ, glitchaddr, Validate=False, maxResp=8)
 
         if current is None or len(current) < 8:
-            logging.warning('Glitch Module not present?')
+            glitch_logger.warning('Glitch Module not present?')
             return
 
         LSB = fine & 0x00FF
@@ -692,7 +698,7 @@ class ChipWhispererGlitch(object):
         current = self.oa.sendMessage(CODE_READ, glitchaddr, Validate=False, maxResp=8)
 
         if current is None or len(current) < 8:
-            logging.warning('Glitch Module not present?')
+            glitch_logger.warning('Glitch Module not present?')
             return
 
         LSB = fine & 0x00FF
@@ -751,8 +757,8 @@ class ChipWhispererGlitch(object):
         """Check if the DCMs are locked and print results """
 
         stat = self.getDCMStatus()
-        logging.info('DCM1: Phase %d, Locked %r' % (stat[0], stat[2]))
-        logging.info('DCM2: Phase %d, Locked %r' % (stat[1], stat[3]))
+        glitch_logger.info('DCM1: Phase %d, Locked %r' % (stat[0], stat[2]))
+        glitch_logger.info('DCM2: Phase %d, Locked %r' % (stat[1], stat[3]))
 
     def setNumGlitches(self, num):
         """Set number of glitches to occur after a trigger"""
@@ -760,7 +766,7 @@ class ChipWhispererGlitch(object):
         resp = self.oa.sendMessage(CODE_READ, glitchaddr, Validate=False, maxResp=8)
 
         if resp is None or len(resp) < 8:
-            logging.warning('Glitch Module not present?')
+            glitch_logger.warning('Glitch Module not present?')
             return
 
         if num < 1:
